@@ -2,15 +2,16 @@ from .auto import *
 import click
 import sys
 from os import system
+from random import choice
 
 developer = {"name": "정지효 (Jung Ji-Hyo)", "email": "cord0318@gmail.com", "age": "13"}
-key = {"right":"<ctrl>+v", "left":"<ctrl>+x"}
+key = {"right":"v", "left":"x"}
 
 def check_version():
-    version = "0.0.10"
+    version = "0.0.11"
     click.echo("autoclick " + version)
 
-cmd_list = ["set_autoclick_key (키 바꾸기)", "developer (개발자)", "friend (도와준 친구)"]
+cmd_list = ["contact", "developer (개발자)", "friend (도와준 친구)"]
 
 def print_menu():
     system("cls")
@@ -22,16 +23,17 @@ def cmd():
     cmd = int(input("> "))
     if cmd == 0:
         try:
+            discord_message = ["(Please buy me Discord NITRO...)", "(Please send me message!)", "(Please send me friend)"]
             system("cls")
-            click.echo("바꾸실 키를 적어주세요. ex) <alt>+x <alt>+v")
-            cmd = input("> ").split()
-            auto_click = AutoClick().set_autoclick_key(cmd[0], cmd[1])
-            click.echo("성공적으로 키를 바꾸었습니다!")
-            exit()
+            click.echo("My Discord : 정지효#6521 " + choice(discord_message))
+            click.echo("My Email : cord0318@gmail.com")
+            system("cls")
+            system("auto")
 
         except Exception as e:
             click.echo("알수 없는 오류가 나타났습니다.\n오류 코드 : " + e)
-            exit()
+            system("cls")
+            system("auto")
     elif cmd == 1:
         system("cls")
         for dev in developer:
@@ -40,6 +42,8 @@ def cmd():
     elif cmd == 2:
         system("cls")
         click.echo("이 개발을 도와준 '위정우'에게 감사움을 표합니다.\n")
+        system("cls")
+        system("auto")
 
 def set_key(key_type, key_val):
     global key
